@@ -230,6 +230,10 @@ class SupabaseFile(AbstractBufferedFile):
 
 
 class SupabaseFileSystemSettings(EnvSettings):
+    # SUPABASE_FS_BUCKET_EXTERNAL
+    bucket_external: str = Field()
+    # SUPABASE_FS_BUCKET_INTERNAL
+    bucket_internal: str = Field()
     # SUPABASE_FS_API_KEY
     api_key: str = Field(exclude=True)
     # SUPABASE_FS_API_URL
@@ -669,14 +673,23 @@ class SupabaseFileSystem(ProxyFileSystem, WithLogger):
         fs: FileSystem,
     ) -> None:
         # Use generic test buckets for all tests
-        fs_bucket_suffix = "test" if env.is_test else env.name
+        bucket_external_value = (
+            f"{settings.bucket_external}-test"
+            if env.is_test or env.is_ci
+            else settings.bucket_external
+        )
         self._bucket_external = FileSystemBucket(
             bucket_type="external",
-            value=f"application-external-storage-{fs_bucket_suffix}",
+            value=bucket_external_value,
+        )
+        bucket_internal_value = (
+            f"{settings.bucket_internal}-test"
+            if env.is_test or env.is_ci
+            else settings.bucket_internal
         )
         self._bucket_internal = FileSystemBucket(
             bucket_type="internal",
-            value=f"application-internal-storage-{fs_bucket_suffix}",
+            value=bucket_internal_value,
         )
         fs.register_proxyfs(self, "sb")
 
