@@ -7,9 +7,9 @@ from apppy.db.postgres import PostgresClient
 class SupabaseMigrations(Migrations):
     def __init__(
         self,
-        postgres_client: PostgresClient,
+        postgres: PostgresClient,
     ):
-        self._postgres_client = postgres_client
+        self._postgres = postgres
 
     async def head(self) -> str | None:
         latest_migration_query = """
@@ -19,7 +19,7 @@ class SupabaseMigrations(Migrations):
         LIMIT 1
         """
         try:
-            result_set = await self._postgres_client.db_query_async(latest_migration_query)
+            result_set = await self._postgres.db_query_async(latest_migration_query)
             if result_set is None or len(result_set) != 1:
                 return None
 
